#' Costa Rica national boundary
#'
#' An `sf` object with the national boundary of Costa Rica from GADM.
#'
#' @format An `sf` object with 1 row and the following columns:
#' \describe{
#'   \item{GID_0}{Country code (CRI)}
#'   \item{COUNTRY}{Country name}
#'   \item{geometry}{MULTIPOLYGON geometry}
#' }
#' @source \url{https://gadm.org/}
"cr_outline"
