% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bdcr_occurrences.R
\name{bdcr_occurrences}
\alias{bdcr_occurrences}
\title{Download occurrence records from BIODATACR}
\usage{
bdcr_occurrences(taxon, rows = 100, start = 0)
}
\arguments{
\item{taxon}{Character. Scientific name of the taxon.}

\item{rows}{Integer. Maximum number of records to download. Default 100.}

\item{start}{Integer. Starting record for pagination. Default 0.}
}
\value{
A `tibble` with columns: `scientificName`, `vernacularName`,
  `decimalLatitude`, `decimalLongitude`, `year`, `month`,
  `basisOfRecord`, `dataResourceName`, `country`, `family`,
  `species`, `collector`, `license`, `geospatialKosher`,
  `taxonomicKosher`.
}
\description{
Download occurrence records from BIODATACR
}
\examples{
\dontrun{
bdcr_occurrences("Panthera onca", rows = 50)
}
}
