% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bdcr_count.R
\name{bdcr_count}
\alias{bdcr_count}
\title{Count occurrence records for a taxon}
\usage{
bdcr_count(taxon)
}
\arguments{
\item{taxon}{Character. Scientific name (e.g. `"Panthera onca"`).}
}
\value{
Integer with the total number of available records.
}
\description{
Count occurrence records for a taxon
}
\examples{
\dontrun{
bdcr_count("Panthera onca")
}
}
