% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bdcr_species_search.R
\name{bdcr_species_search}
\alias{bdcr_species_search}
\title{Search for taxonomic information of a species in BIODATACR}
\usage{
bdcr_species_search(name, rows = 10)
}
\arguments{
\item{name}{Character. Scientific name (may be a synonym or partial name).}

\item{rows}{Integer. Maximum number of results. Default 10.}
}
\value{
A `tibble` with columns: `name`, `guid`, `commonName`,
  `scientificName`, `rank`, `taxonomicStatus`, `nameComplete`.
}
\description{
Queries the BIE (Biodiversity Information Explorer) index of BIODATACR
to retrieve taxonomic information for a species.
}
\examples{
\dontrun{
bdcr_species_search("Panthera onca")
}
}
